cliplock

package
v1.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package cliplock serializes system clipboard access between test processes: go test ./... runs packages in parallel and they all share one clipboard.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Lock

func Lock(tb testing.TB)

Lock blocks until tb holds the clipboard lock; it is released when tb finishes. The OS drops the lock if the process dies. It is not reentrant: calling Lock again before tb finishes (e.g. in a subtest) deadlocks.

Types

This section is empty.

Jump to